@@ -12,6 +12,8 @@ OC.L10N.register(
     "Mail" : "Pos",
     "Mails" : "E-pos",
     "💌 A mail app for Nextcloud" : "💌 ’n E-postoep vir Nextcloud",
+    "Save" : "Stoor",
+    "Connect" : "Verbind",
     "Name" : "Naam",
     "Mail address" : "Posadres",
     "Password" : "Wagwoord",
@@ -31,8 +33,6 @@ OC.L10N.register(
     "SMTP Port" : "SMTP-poort",
     "SMTP User" : "SMTP-gebruiker",
     "SMTP Password" : "SMTP-wagwoord",
-    "Save" : "Stoor",
-    "Connect" : "Verbind",
     "Account settings" : "Rekeninginstellings",
     "Aliases" : "Aliasse",
     "Signature" : "Handtekening",
@@ -44,24 +44,25 @@ OC.L10N.register(
     "Add mail account" : "Voeg posrekening toe",
     "General" : "Algemeen",
     "Register" : "Registreer",
+    "About" : "Aangaande",
     "Keyboard shortcuts" : "Sneltoetse",
     "Archive" : "Argief",
     "Delete" : "Skrap",
     "Search" : "Soek",
     "Send" : "Stuur",
     "Refresh" : "Verfris",
-    "Update Certificate" : "Werk sertifikaat by",
     "No certificate" : "Geen sertifikaat",
     "Certificate updated" : "Sertifikaat bygewerk",
     "Could not update certificate" : "Kon nie sertifikaat bywerk nie",
     "{commonName} - Valid until {expiryDate}" : "{commonName} - Geldig tot {expiryDate}",
+    "Update Certificate" : "Werk sertifikaat by",
+    "Send later" : "Stuur later",
     "From" : "Van",
     "Select account" : "Kies rekening",
     "To" : "Aan",
     "Contact or email address …" : "Kontak of e-posadres …",
     "Subject" : "Onderwerp",
     "Write message …" : "Skryf boodskap…",
-    "Send later" : "Stuur later",
     "Send now" : "Stuur nou",
     "Tomorrow morning" : "Môreoggend",
     "Tomorrow afternoon" : "Môremiddag",
@@ -71,9 +72,9 @@ OC.L10N.register(
     "Choose" : "Kies",
     "Confirm" : "Bevestig",
     "Plain text" : "Skoonteks",
+    "No subject" : "Geen onderwerp",
     "Favorite" : "Gunsteling",
     "Back" : "Terug",
-    "No subject" : "Geen onderwerp",
     "All day" : "Heeldag",
     "Description" : "Beskrywing",
     "Create" : "Skep",
@@ -86,18 +87,17 @@ OC.L10N.register(
     "Forward" : "Stuur aan",
     "View source" : "Bekyk bron",
     "Message body" : "Boodskaplyfteks",
+    "Unnamed" : "Naamloos",
     "Import into calendar" : "Voer in na kalender",
     "Download attachment" : "Laai aanhangsel af",
-    "Unnamed" : "Naamloos",
     "Move" : "Skuif",
+    "Loading …" : "Laai …",
+    "Remove account" : "Verwyder rekening",
     "Quota" : "Kwota",
     "Saving" : "Stoor tans",
-    "Remove account" : "Verwyder rekening",
-    "Loading …" : "Laai …",
     "New message" : "Nuwe boodskap",
-    "Retry" : "Herprobeer",
-    "Sending …" : "Stuur…",
     "Reply" : "Antwoord",
+    "Retry" : "Herprobeer",
     "Add" : "Voeg by",
     "Date" : "Datum",
     "Tags" : "Etikette",
@@ -126,6 +126,7 @@ OC.L10N.register(
     "Forwarding to %s" : "Stuur aan na %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
     "Redirect" : "Herverwys",
-    "The link leads to %s" : "Die skakel lei na %s"
+    "The link leads to %s" : "Die skakel lei na %s",
+    "Sending …" : "Stuur…"
 },
 "nplurals=2; plural=(n != 1);");
