@@ -19,6 +19,27 @@ OC.L10N.register(
     "Sent messages are saved in:" : "Изпратените съобщения се запазват в:",
     "Deleted messages are moved in:" : "Изтритите съобщения се преместват в:",
     "Archived messages are moved in:" : "Архивираните съобщения са преместени в:",
+    "Connecting" : "Свързване",
+    "Reconnect Google account" : "Повторно свързване на профил в Google",
+    "Sign in with Google" : "Вписване с Google",
+    "Save" : "Запис",
+    "Connect" : "Свържи",
+    "Looking up configuration" : "Търсене на конфигурация",
+    "Checking mail host connectivity" : "Проверка на сврзаност с пощенския сървър",
+    "Configuration discovery failed. Please use the manual settings" : "Неуспешно откриване на конфигурация. Моля, използвайте ръчните настройки",
+    "Password required" : "Паролата е задължителна",
+    "Testing authentication" : "Тестване на удостоверяване",
+    "Awaiting user consent" : "Очаква се съгласието на потребителя",
+    "Loading account" : "Зареждане на профил",
+    "Account updated" : "Профилът е актуализиран",
+    "IMAP server is not reachable" : "IMAP сървърът не е достъпен",
+    "SMTP server is not reachable" : "SMTP IMAP сървърът не е достъпен",
+    "IMAP username or password is wrong" : "Грешно IMAP име на потребител или парола",
+    "SMTP username or password is wrong" : "Грешно SMTP име на потребител или парола",
+    "IMAP connection failed" : "IMAP връзката прекъсна",
+    "SMTP connection failed" : "SMTP връзката прекъсна",
+    "Authorization pop-up closed" : "Затворен е изскачащият прозорец за оторизация",
+    "There was an error while setting up your account" : "Възникна грешка при настройката на вашия профил",
     "Auto" : "Автоматично",
     "Name" : "Име",
     "Mail address" : "Имейл адрес",
@@ -42,27 +63,6 @@ OC.L10N.register(
     "SMTP User" : "SMTP потребител",
     "SMTP Password" : "SMTP парола",
     "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "За да може Google профил да работи с това приложение, трябва да активирате двустепенно удостоверяване за Google и да генерирате парола за приложението.",
-    "Connecting" : "Свързване",
-    "Reconnect Google account" : "Повторно свързване на профил в Google",
-    "Sign in with Google" : "Вписване с Google",
-    "Save" : "Запис",
-    "Connect" : "Свържи",
-    "Looking up configuration" : "Търсене на конфигурация",
-    "Checking mail host connectivity" : "Проверка на сврзаност с пощенския сървър",
-    "Configuration discovery failed. Please use the manual settings" : "Неуспешно откриване на конфигурация. Моля, използвайте ръчните настройки",
-    "Password required" : "Паролата е задължителна",
-    "Testing authentication" : "Тестване на удостоверяване",
-    "Awaiting user consent" : "Очаква се съгласието на потребителя",
-    "Loading account" : "Зареждане на профил",
-    "Account updated" : "Профилът е актуализиран",
-    "IMAP server is not reachable" : "IMAP сървърът не е достъпен",
-    "SMTP server is not reachable" : "SMTP IMAP сървърът не е достъпен",
-    "IMAP username or password is wrong" : "Грешно IMAP име на потребител или парола",
-    "SMTP username or password is wrong" : "Грешно SMTP име на потребител или парола",
-    "IMAP connection failed" : "IMAP връзката прекъсна",
-    "SMTP connection failed" : "SMTP връзката прекъсна",
-    "Authorization pop-up closed" : "Затворен е изскачащият прозорец за оторизация",
-    "There was an error while setting up your account" : "Възникна грешка при настройката на вашия профил",
     "Account settings" : "Настройки на профила",
     "Aliases" : "Псевдоними",
     "Alias to S/MIME certificate mapping" : "Съпоставка на псевдоним със S/MIME сертификат",
@@ -73,7 +73,6 @@ OC.L10N.register(
     "Default folders" : "Папки по подразбиране",
     "Autoresponder" : "Автоматичен отговор",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматичен отговор на входящите съобщения. Ако някой ви изпрати няколко съобщения, този автоматичен отговор ще бъде изпращан най-много веднъж на всеки 4 дни.",
-    "Please connect to a sieve server first." : "Моля да се свържете първо със сървъра на ситото",
     "Filters" : "Филтри",
     "Mail server" : "Имейл сървър",
     "Update alias" : "Актуализиране на псевдоним",
@@ -86,6 +85,8 @@ OC.L10N.register(
     "Add alias" : "Добавяне на псевдоним",
     "Create alias" : "Създаване на псевдоним",
     "Cancel" : "Отказ",
+    "Put my text to the bottom of a reply instead of on top of it." : "Поставяне на моя текст в долната част на отговора, вместо над него.",
+    "Could not update preference" : "Предпочитанието не можа да се актуализира",
     "Mail settings" : "Настройки на пощата",
     "Add mail account" : "Добавяне на профил",
     "General" : "Общи",
@@ -99,6 +100,7 @@ OC.L10N.register(
     "Trusted senders" : "Доверени податели",
     "Manage S/MIME certificates" : "Управление на S/MIME сертификати",
     "Looking for a way to encrypt your emails?" : "Търсите ли начин да шифровате имейлите си?",
+    "About" : "Относно",
     "Keyboard shortcuts" : "Бързи клавиши",
     "Compose new message" : "Създай ново съобщение",
     "Newer message" : "Следващо съобщение",
@@ -110,14 +112,23 @@ OC.L10N.register(
     "Search" : "Търси",
     "Send" : "Изпрати",
     "Refresh" : "Опресняване",
-    "Put my text to the bottom of a reply instead of on top of it." : "Поставяне на моя текст в долната част на отговора, вместо над него.",
-    "Could not update preference" : "Предпочитанието не можа да се актуализира",
-    "Select an alias" : "Избор на псевдоним",
-    "Update Certificate" : "Актуализиране на сертификат",
     "No certificate" : "Няма сертификат",
     "Certificate updated" : "Актуализиран е сертификат",
     "Could not update certificate" : "Сертификата не можа да се актуализира",
     "{commonName} - Valid until {expiryDate}" : "{commonName} - Валидно до {expiryDate}",
+    "Select an alias" : "Избор на псевдоним",
+    "Update Certificate" : "Актуализиране на сертификат",
+    "Encrypt with S/MIME and send later" : "Криптиране със S/MIME и изпращане по-късно",
+    "Encrypt with S/MIME and send" : "Криптиране със S/MIME и изпращане",
+    "Encrypt with Mailvelope and send later" : "Криптиране с Mailvelope и изпращане по-късно",
+    "Encrypt with Mailvelope and send" : "Криптиране с Mailvelope и изпращане",
+    "Send later" : "Изпратете по-късно",
+    "Message {id} could not be found" : "Съобщението {id} не можа да бъде намерено",
+    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Избрано е подписване или криптиране със S/MIME, но нямаме сертификат за избрания псевдоним. Съобщението няма да бъде подписано или криптирано.",
+    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Всяко съществуващо форматиране (например удебеляване, курсив, подчертани или вградени изображения) ще бъде премахнато.",
+    "Turn off formatting" : "Изключване на форматирането",
+    "Turn off and remove formatting" : "Изключване и премахване на форматирането",
+    "Keep formatting" : " Запазване /продължаване/ на форматирането",
     "From" : "От",
     "Select account" : "Избери профил",
     "To" : "До",
@@ -141,7 +152,6 @@ OC.L10N.register(
     "Upload attachment" : "Качи прикачен файл/ове",
     "Add attachment from Files" : "Прикачи от \"Файлове\"",
     "Smart picker" : "Смарт /интелигентен/ инструмент за избор",
-    "Send later" : "Изпратете по-късно",
     "Request a read receipt" : "Заявка на разписка за четене",
     "Sign message with S/MIME" : "Подписване на съобщение със S/MIME/сертификат/",
     "Encrypt message with S/MIME" : "Криптиране на съобщение със S/MIME",
@@ -152,25 +162,20 @@ OC.L10N.register(
     "Monday morning" : "Понеделник сутрин",
     "Custom date and time" : "Персонализирана дата и час",
     "Enter a date" : "Въведете дата",
-    "Encrypt with S/MIME and send later" : "Криптиране със S/MIME и изпращане по-късно",
-    "Encrypt with S/MIME and send" : "Криптиране със S/MIME и изпращане",
-    "Encrypt with Mailvelope and send later" : "Криптиране с Mailvelope и изпращане по-късно",
-    "Encrypt with Mailvelope and send" : "Криптиране с Mailvelope и изпращане",
-    "Message {id} could not be found" : "Съобщението {id} не можа да бъде намерено",
-    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Избрано е подписване или криптиране със S/MIME, но нямаме сертификат за избрания псевдоним. Съобщението няма да бъде подписано или криптирано.",
-    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Всяко съществуващо форматиране (например удебеляване, курсив, подчертани или вградени изображения) ще бъде премахнато.",
-    "Turn off formatting" : "Изключване на форматирането",
-    "Turn off and remove formatting" : "Изключване и премахване на форматирането",
-    "Keep formatting" : " Запазване /продължаване/ на форматирането",
+    "Choose" : "Изберете",
     "Choose a file to add as attachment" : "Избери файл за прикачване",
     "Choose a file to share as a link" : "Изберете файл, който да споделите като връзка",
-    "Choose" : "Изберете",
     "_{count} attachment_::_{count} attachments_" : ["{count} прикачени файлове","{count} прикачени файлове"],
     "Confirm" : "Потвърдете",
     "Plain text" : "Обикновен текст",
     "Rich text" : "Форматиран текст",
     "No messages in this mailbox" : "Няма съобщения в тази пощенска кутия",
     "No messages" : "Няма съобщения.",
+    "Blind copy recipients only" : "Само получателите на слепи копия",
+    "No subject" : "Без /няма/ тема",
+    "No trash mailbox configured" : "Няма конфигурирана пощенска кутия за боклук",
+    "Could not delete message" : "Съобщението не може да бъде изтрито",
+    "Could not archive message" : "Не можа да се архивира съобщение",
     "Draft: " : "Чернова: ",
     "Encrypted message" : "Криптирано съобщение",
     "This message is unread" : "Това съобщение не е прочетено",
@@ -191,11 +196,6 @@ OC.L10N.register(
     "Create event" : "Създаване на събитие",
     "Create task" : "Създаване на задача",
     "Download message" : "Изтегляне на съобщение",
-    "Blind copy recipients only" : "Само получателите на слепи копия",
-    "No subject" : "Без /няма/ тема",
-    "No trash mailbox configured" : "Няма конфигурирана пощенска кутия за боклук",
-    "Could not delete message" : "Съобщението не може да бъде изтрито",
-    "Could not archive message" : "Не можа да се архивира съобщение",
     "Load more" : "Зареждане на още",
     "_Mark {number} read_::_Mark {number} read_" : ["Маркиране {number} прочетено","Маркиране {number} прочетено"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Маркиране {number} непрочетено","Маркиране {number} непрочетено"],
@@ -207,10 +207,16 @@ OC.L10N.register(
     "_Move {number} thread_::_Move {number} threads_" : ["Преместване на {number} нишки","Преместване на {number} нишки"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препращане {number} като прикачен файл","Препращане {number} като прикачен файл"],
     "Report this bug" : "Докладване на тази грешка",
-    "All day" : "Цял ден",
-    "Create" : "Създаване",
     "Event created" : "Събитието е създадено",
     "Could not create event" : "Несупешно създаване на събитие",
+    "All day" : "Цял ден",
+    "Create" : "Създаване",
+    "This event was updated" : "Това събитие беше актуализирано",
+    "{attendeeName} accepted your invitation" : "{attendeeName} прие вашата покана",
+    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} прие вашата покана условно",
+    "{attendeeName} declined your invitation" : "{attendeeName} е отхвърлил поканата ви",
+    "{attendeeName} reacted to your invitation" : "{attendeeName} реагира на вашата покана",
+    "Failed to save your participation status" : "Неуспешно записване на статуса ви на участие",
     "You accepted this invitation" : "Приехте тази покана",
     "You tentatively accepted this invitation" : "Вие приехте тази покана условно",
     "You declined this invitation" : "Отхвърлихте поканата",
@@ -224,45 +230,39 @@ OC.L10N.register(
     "Decline" : "Отхвърляне",
     "Tentatively accept" : "Приемам условно",
     "More options" : "Още опции",
-    "This event is in the past." : "Това събитие е отминало.",
-    "This event was updated" : "Това събитие беше актуализирано",
-    "{attendeeName} accepted your invitation" : "{attendeeName} прие вашата покана",
-    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} прие вашата покана условно",
-    "{attendeeName} declined your invitation" : "{attendeeName} е отхвърлил поканата ви",
-    "{attendeeName} reacted to your invitation" : "{attendeeName} реагира на вашата покана",
-    "Failed to save your participation status" : "Неуспешно записване на статуса ви на участие",
+    "individual" : "Индивидуален",
     "domain" : "домейн",
     "Remove" : "Премахване",
     "email" : "имейл",
-    "individual" : "Индивидуален",
     "Itinerary for {type} is not supported yet" : "Маршрутът за {type} все още не се поддържа",
+    "To archive a message please configure an archive mailbox in account settings" : "За архивиране на съобщение, конфигурирайте архивна пощенска кутия в настройките на вашият профил",
+    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Нямате право да преместите това съобщение в архивната папка и/или да изтриете това съобщение от текущата папка",
     "Could not open mailbox" : "Пощенската кутия не можа да се отвори",
     "Loading messages …" : "Зареждане на съобщения ...",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Индексиране на вашите съобщения. Това може да отнеме малко повече време за по-големи пощенски кутии.",
-    "To archive a message please configure an archive mailbox in account settings" : "За архивиране на съобщение, конфигурирайте архивна пощенска кутия в настройките на вашият профил",
-    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Нямате право да преместите това съобщение в архивната папка и/или да изтриете това съобщение от текущата папка",
     "Choose target mailbox" : "Избор на целева пощенска кутия ",
     "No more submailboxes in here" : "Тук няма повече допълнителни пощенски кутии",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Съобщенията автоматично ще бъдат маркирани като важни въз основа на съобщенията, с които сте взаимодействали или маркирани като важни. В началото може да се наложи ръчно да промените важността, за да обучите системата, но тя ще се подобри с течение на времето.",
     "Important info" : "Важна информация",
     "Other" : "Друг",
-    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Съобщенията автоматично ще бъдат маркирани като важни въз основа на съобщенията, с които сте взаимодействали или маркирани като важни. В началото може да се наложи ръчно да промените важността, за да обучите системата, но тя ще се подобри с течение на времето.",
+    "Could not send mdn" : "Не можа да се изпрати mdn",
     "The sender of this message has asked to be notified when you read this message." : "Подателят на това съобщение поиска да бъде уведомен, когато прочетете това съобщение.",
     "Notify the sender" : "Уведомяване на подателя",
     "You sent a read confirmation to the sender of this message." : "Изпратихте потвърждение за четене на подателя на това съобщение.",
-    "Could not send mdn" : "Не можа да се изпрати mdn",
     "Forward" : "Напред",
     "Move message" : "Преместване на съобщението",
+    "Translate" : "Превод",
     "Forward message as attachment" : "Препращане на съобщението като прикачен файл",
     "View source" : "Преглед на източника",
     "Download thread data for debugging" : "Изтегля данните за нишките за отстраняване на грешки",
     "Message body" : "Тяло на съобщението",
     "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Предупреждение: S/MIME подписът на това съобщение не е потвърден. Възможно е подателят да се представя /въплъщава/ за някого!",
+    "Unnamed" : "Без име",
+    "Embedded message" : "Вградено съобщение",
     "Choose a folder to store the attachment in" : "Избери папка, където да бъде запазен прикаченият файл",
     "Import into calendar" : "Импортиране в календар",
     "Download attachment" : "Изтегли прикачените файлове",
     "Save to Files" : "Запази във Файлове",
-    "Unnamed" : "Без име",
-    "Embedded message" : "Вградено съобщение",
     "View fewer attachments" : "Вижте по-малко прикачени файлове",
     "Choose a folder to store the attachments in" : "Избор на папка, където да бъдат запазени прикачените файлове",
     "Save all to Files" : "Записване на всички към Файлове",
@@ -280,6 +280,12 @@ OC.L10N.register(
     "Moving" : "Преместване ",
     "Moving thread" : "Нишката се премества",
     "Moving message" : "Съобщението се премества",
+    "Loading …" : "Зарежда …",
+    "Not supported by the server" : "Не се поддържа от сървъра",
+    "{usage} of {limit} used" : "{usage} от {limit}  използвани",
+    "Remove account" : "Изтриване",
+    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Профилът за {email} и кешираните имейл данни ще бъдат премахнати от Nextcloud, но не и от вашия доставчик на електронна поща.",
+    "Remove {email}" : "Премахване {email}",
     "Provisioned account is disabled" : "Осигуреният профил е деактивиран",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Моля, да се впишете с парола, за да активирате този профил. Текущата сесия използва удостоверяване без парола, напр. SSO или WebAuthn.",
     "Quota" : "Квота",
@@ -288,15 +294,18 @@ OC.L10N.register(
     "Saving" : "Запазване",
     "Move up" : "Преместване нагоре",
     "Move down" : "Преместване  надолу",
-    "Remove account" : "Изтриване",
-    "Loading …" : "Зарежда …",
-    "Not supported by the server" : "Не се поддържа от сървъра",
-    "{usage} of {limit} used" : "{usage} от {limit}  използвани",
-    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Профилът за {email} и кешираните имейл данни ще бъдат премахнати от Nextcloud, но не и от вашия доставчик на електронна поща.",
-    "Remove {email}" : "Премахване {email}",
     "Show all subscribed mailboxes" : "Показване на всички абонирани пощенски кутии",
     "Show all mailboxes" : "Показване на всички пощенски кутии",
     "Collapse mailboxes" : "Свиване на пощенските кутии",
+    "_{total} message_::_{total} messages_" : ["{total} съобщения","{total} съобщения"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочетени от {total}","{unread} непрочетени от {total}"],
+    "All messages in mailbox will be deleted." : "Всички съобщения в пощенската кутия ще бъдат изтрити.",
+    "Clear mailbox {name}" : "Изчистване на пощенска кутия {name}",
+    "Clear mailbox" : "Изчистване на пощенска кутия",
+    "The mailbox and all messages in it will be deleted." : "Пощенската кутия и всички съобщения в нея ще бъдат изтрити.",
+    "Delete mailbox" : "Изтриване на пощенска кутия",
+    "Delete mailbox {name}" : "Изтриване на пощенска кутия {name}",
+    "An error occurred, unable to rename the mailbox." : "Възникна грешка, не можа да се преименува пощенската кутия.",
     "Mark all as read" : "Маркирай всички като прочетени",
     "Mark all messages of this mailbox as read" : "Маркирай всички съобщения в тази пощенска кутия като прочетени",
     "Add submailbox" : "Добавяне на допълнителна пощенска кутия",
@@ -306,22 +315,8 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Изчистете локално кеширани данни, в случай че има проблеми със синхронизирането.",
     "Subscribed" : "Абониран",
     "Sync in background" : "Синхронизиране във фонов режим",
-    "Clear mailbox" : "Изчистване на пощенска кутия",
-    "Delete mailbox" : "Изтриване на пощенска кутия",
-    "All messages in mailbox will be deleted." : "Всички съобщения в пощенската кутия ще бъдат изтрити.",
-    "Clear mailbox {name}" : "Изчистване на пощенска кутия {name}",
-    "The mailbox and all messages in it will be deleted." : "Пощенската кутия и всички съобщения в нея ще бъдат изтрити.",
-    "Delete mailbox {name}" : "Изтриване на пощенска кутия {name}",
-    "An error occurred, unable to rename the mailbox." : "Възникна грешка, не можа да се преименува пощенската кутия.",
-    "_{total} message_::_{total} messages_" : ["{total} съобщения","{total} съобщения"],
     "Outbox" : "Изходящи",
     "New message" : "Ново съобщение",
-    "Error sending your message" : "Грешка при изпращне на вашето съобщение.",
-    "Retry" : "Опитай отново",
-    "Uploading attachments …" : "Качване на прикачените файлове ...",
-    "Sending …" : "Изпращане...",
-    "Warning sending your message" : "Предупреждение за изпращане на вашето съобщение",
-    "Send anyway" : " Все пак го изпратете",
     "Edit message" : "Редактиране на съобщение",
     "Draft" : "Чернова",
     "Reply" : "Отговори",
@@ -329,6 +324,10 @@ OC.L10N.register(
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Опитвате се да изпратите до много получатели в полето До и/или Копие. Помислете за използването на Bcc, за да скриете адресите на получателите.",
     "Message discarded" : "Съобщението е отхвърлено",
     "Could not discard message" : "Съобщението не можа да бъде отхвърлено",
+    "Error sending your message" : "Грешка при изпращне на вашето съобщение.",
+    "Retry" : "Опитай отново",
+    "Warning sending your message" : "Предупреждение за изпращане на вашето съобщение",
+    "Send anyway" : " Все пак го изпратете",
     "Autoresponder off" : "Автоматичният отговор е изключен",
     "Autoresponder on" : "Автоматичният отговор е включен",
     "First day" : "Първи ден",
@@ -341,14 +340,17 @@ OC.L10N.register(
     "Pending or not sent messages will show up here" : "Чакащи или неизпратени съобщения ще се показват тук",
     "Message could not be sent" : "Съобщението не можа да бъде изпратено",
     "Message deleted" : "Съобщението е изтрито ",
+    "Copied email address to clipboard" : "Копиран е имейл адрес в клипборда",
+    "Could not copy email address to clipboard" : "Неуспешно копиране на имейл адреса в клипборда",
     "Contacts with this address" : "Контакти с този адрес",
     "Add to Contact" : "Добавяне към контакт",
     "New Contact" : "Нов контакт",
     "Copy to clipboard" : "Копиране в клипборда",
     "Contact name …" : "Име за контакт …",
     "Add" : "Добавяне",
-    "Copied email address to clipboard" : "Копиран е имейл адрес в клипборда",
-    "Could not copy email address to clipboard" : "Неуспешно копиране на имейл адреса в клипборда",
+    "Show less" : "Покажи по-малко",
+    "Show more" : "Покажи повече",
+    "Clear" : "Изчистване",
     "Search in mailbox" : "Търсене в пощенската кутия",
     "Close" : "Затваряне",
     "Search parameters" : "Параметри на търсенето",
@@ -364,7 +366,6 @@ OC.L10N.register(
     "Select tags" : "Избор на етикети",
     "Marked as" : "Маркиран/о като",
     "Has attachments" : "Има прикачени файлове",
-    "Clear" : "Изчистване",
     "Sieve Port" : "Порт на Сито",
     "Custom" : "Персонализиран",
     "Sieve User" : "Потребител на Сито",
@@ -375,23 +376,29 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Подписът ви е по-голям от 2 MB. Това може да се отрази на работата на  вашия редактор.",
     "Save signature" : "Запис на подпис",
     "Place signature above quoted text" : "Поставяне на подпис над цитирания текст",
+    "An error occurred, unable to rename the tag." : "Възникна грешка, не може да се преименува етикет.",
     "Saving new tag name …" : "Запазва се името на нов етикет …",
     "Delete tag" : "Изтрий таг",
     "Set tag" : "Задаване на етикет",
     "Unset tag" : "Отмяна на етикет",
-    "An error occurred, unable to rename the tag." : "Възникна грешка, не може да се преименува етикет.",
-    "Add default tags" : "Добавяне на етикети по подразбиране",
-    "Add tag" : "Добавяне на етикет",
-    "Saving tag …" : "Записване на етикет ...",
     "Tag name is a hidden system tag" : "Името на етикета е скрит системен етикет",
     "Tag already exists" : "Етикетът вече съществува",
     "An error occurred, unable to create the tag." : "Възникна грешка, не може да се създаде етикет.",
-    "Loading thread" : "Зареждане на нишка",
-    "Not found" : "Не е намерен",
+    "Add default tags" : "Добавяне на етикети по подразбиране",
+    "Add tag" : "Добавяне на етикет",
+    "Saving tag …" : "Записване на етикет ...",
     "Could not load your message thread" : " Нишката на вашето съобщение не можа да се зареди",
     "The thread doesn't exist or has been deleted" : "Нишката не съществува или е била изтрита",
-    "Unsubscribe" : "Отписване",
+    "Loading thread" : "Зареждане на нишка",
+    "Not found" : "Не е намерен",
+    "Encrypted & verified " : "Криптирано и потвърдено",
+    "Signature verified" : "Подписът е потвърден",
+    "Signature unverified " : "Подписът не е потвърден",
+    "This message was encrypted by the sender before it was sent." : "Това съобщение е било криптирано от изпращача преди да бъде изпратено.",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Това съобщение съдържа проверен цифров подпис S/MIME. Съобщението не е променяно след изпращането му.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Това съобщение съдържа непроверен цифров S/MIME подпис. Възможно е съобщението да е било променено, след както е изпратено, или сертификатът на подписаният да е ненадежден.",
     "Reply all" : "Отговаряне на всички",
+    "Unsubscribe" : "Отписване",
     "Reply to sender only" : "Отговор само на подателя",
     "Mark as unfavorite" : "Маркиране като непредпочитано",
     "Mark as favorite" : "Маркиране като любими",
@@ -401,29 +408,31 @@ OC.L10N.register(
     "Delete message" : "Изтриване на съобщението",
     "Message source" : "Източник на съобщение",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Прекратяването на абонамента ще спре всички съобщения от пощенския списък {sender}",
-    "Encrypted & verified " : "Криптирано и потвърдено",
-    "Signature verified" : "Подписът е потвърден",
-    "Signature unverified " : "Подписът не е потвърден",
-    "This message was encrypted by the sender before it was sent." : "Това съобщение е било криптирано от изпращача преди да бъде изпратено.",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Това съобщение съдържа проверен цифров подпис S/MIME. Съобщението не е променяно след изпращането му.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Това съобщение съдържа непроверен цифров S/MIME подпис. Възможно е съобщението да е било променено, след както е изпратено, или сертификатът на подписаният да е ненадежден.",
-    "No senders are trusted at the moment." : "В момента няма доверени податели.",
     "Could not remove trusted sender {sender}" : "Не можа да бъде премахнат доверен подател {sender}",
-    "(organizer)" : "(организатор)",
+    "No senders are trusted at the moment." : "В момента няма доверени податели.",
     "Untitled event" : "Събитие без заглавие",
+    "(organizer)" : "(организатор)",
     "Import into {calendar}" : "Импортиране в {calendar}",
     "Event imported into {calendar}" : "Събитието е импортирано в {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Полет {flightNr} от {depAirport} до {arrAirport}",
     "Airplane" : "Самолет",
     "Reservation {id}" : "Резервация {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Полет {flightNr} от {depAirport} до {arrAirport}",
-    "Train" : "Влак",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} от {depStation} до {arrStation}",
     "Train from {depStation} to {arrStation}" : "Влак от {depStation} до {arrStation}",
+    "Train" : "Влак",
     "Flag" : "Знаме",
     "Operator" : "Оператор",
     "Actions" : "Действия",
     "New action" : "Ново действие",
     "Priority" : "Приоритет",
+    "Successfully updated config for \"{domain}\"" : "Конфигурацията за „{domain}“ беше актуализирана успешно",
+    "Error saving config" : "Грешка при записване на конфигурацията",
+    "Saved config for \"{domain}\"" : "Конфигурацията за „{domain}“ е записана",
+    "Could not save provisioning setting" : "Настройката за осигуряване не можа да бъде записана",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Успешно осигурени {count} профили.","Успешно осигурени {count} профили."],
+    "There was an error when provisioning accounts." : "Възникна грешка при осигуряването на профили.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Успешно изтрити и неосигурени профили за „{domain}“",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Грешка при изтриване и неосигуряване на профили за „{domain}“",
     "Mail app" : "Приложение за поща",
     "The mail app allows users to read mails on their IMAP accounts." : "Приложението за поща позволява на потребителите да четат имейли в своите IMAP профили.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Тук можете да намерите настройки за целия екземпляр. Потребителските настройки се намират в самото приложение (долния ляв ъгъл).",
@@ -450,14 +459,10 @@ OC.L10N.register(
     "Microsoft integration" : "Microsoft интеграция",
     "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft позволява на потребителите да имат достъп до електронната си поща чрез IMAP. От съображения за сигурност този достъп е възможен само с връзка OAuth 2.0.",
     "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Трябва да регистрирате ново приложение в портала на Microsoft Azure Active Directory. Добавете URL адреса {url}, като URI адрес за пренасочване.",
-    "Successfully updated config for \"{domain}\"" : "Конфигурацията за „{domain}“ беше актуализирана успешно",
-    "Error saving config" : "Грешка при записване на конфигурацията",
-    "Saved config for \"{domain}\"" : "Конфигурацията за „{domain}“ е записана",
-    "Could not save provisioning setting" : "Настройката за осигуряване не можа да бъде записана",
-    "There was an error when provisioning accounts." : "Възникна грешка при осигуряването на профили.",
-    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Успешно изтрити и неосигурени профили за „{domain}“",
-    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Грешка при изтриване и неосигуряване на профили за „{domain}“",
-    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Успешно осигурени {count} профили.","Успешно осигурени {count} профили."],
+    "Successfully set up anti spam email addresses" : "Успешно настроени имейл адреси срещу нежелана поща",
+    "Error saving anti spam email addresses" : "Грешка при записване на имейл адреси срещу нежелана поща",
+    "Successfully deleted anti spam reporting email" : "Успешно изтрит имейл за сигнали срещу нежелана поща",
+    "Error deleting anti spam reporting email" : "Грешка при изтриването на имейл за сигнали срещу нежелана поща",
     "Anti Spam" : "Защита от нежелана поща",
     "Add the email address of your anti spam report service here." : "Добавяне на имейл адреса на вашата услуга за докладване на нежелана поща тук.",
     "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Когато използвате тази настройка, имейл с отчет ще бъде изпратен до сървъра за отчети за НЕЖЕЛАНА ПОЩА, когато потребителят щракне върху „Маркиране като нежелана поща“.",
@@ -465,22 +470,18 @@ OC.L10N.register(
     "\"Mark as Spam\" Email Address" : "Имейл адрес „Маркиране като нежелана поща“.",
     "\"Mark Not Junk\" Email Address" : "Имейл адрес „Маркиране, че не е отпадък“.",
     "Reset" : "Възстановяване",
-    "Successfully set up anti spam email addresses" : "Успешно настроени имейл адреси срещу нежелана поща",
-    "Error saving anti spam email addresses" : "Грешка при записване на имейл адреси срещу нежелана поща",
-    "Successfully deleted anti spam reporting email" : "Успешно изтрит имейл за сигнали срещу нежелана поща",
-    "Error deleting anti spam reporting email" : "Грешка при изтриването на имейл за сигнали срещу нежелана поща",
-    "Client ID" : "Идентификатор на клиент",
-    "Client secret" : "Тайна на клиент",
-    "Unlink" : "Прекратяване на връзката",
     "Google integration configured" : "Конфигурирана е интеграция с Google",
     "Could not configure Google integration" : "Не можа да се конфигурира интеграцията на Google",
     "Google integration unlinked" : "Премахната е връзката с интеграцията на Google",
     "Could not unlink Google integration" : "Не можа да се премахне връзката с интеграцията на Google",
-    "Tenant ID (optional)" : "Идентификатор на клиент (по избор)",
+    "Client ID" : "Идентификатор на клиент",
+    "Client secret" : "Тайна на клиент",
+    "Unlink" : "Прекратяване на връзката",
     "Microsoft integration configured" : "Конфигурирана е интеграцията на Microsoft",
     "Could not configure Microsoft integration" : "Не можа да се конфигурира интеграцията на Microsoft",
     "Microsoft integration unlinked" : "Премахната е връзката с интеграцията на Microsoft",
     "Could not unlink Microsoft integration" : " Не можа да се премахне връзката с интеграцията на Microsoft",
+    "Tenant ID (optional)" : "Идентификатор на клиент (по избор)",
     "Domain Match: {provisioningDomain}" : "Съвпадение на домейна: {provisioningDomain}",
     "Email: {email}" : "Имейл: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на {host}:{port} ({ssl} криптиране)",
@@ -505,6 +506,11 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "Отмяна на осигурявне и изтриване на конфигурация",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% и %EMAIL% ще бъдат заменени с UID и имейл на потребителя",
     "With the settings above, the app will create account settings in the following way:" : "С настройките по-горе приложението ще създаде настройки на профил по следния начин:",
+    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Предоставеният сертификат PKCS #12 трябва да съдържа поне един сертификат и само един частен ключ.",
+    "Failed to import the certificate. Please check the password." : "Неуспешно импортиране на сертификата. Моля, проверете паролата.",
+    "Certificate imported successfully" : "Успешно импортиране на сертификата",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Неуспешно импортиране на сертификата. Моля, уверете се, че частният ключ съответства на сертификата и не е защитен с парола.",
+    "Failed to import the certificate" : "Неуспешно импортиране на сертификата",
     "S/MIME certificates" : "S/MIME сертификати",
     "Certificate name" : "Име на сертификата",
     "E-mail address" : "Имейл адрес",
@@ -519,11 +525,6 @@ OC.L10N.register(
     "Private key (optional)" : "Частен ключ (по избор)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Частният ключ е необходим само ако възнамерявате да изпращате подписани и криптирани имейли, като използвате този сертификат.",
     "Submit" : "Изпращане",
-    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Предоставеният сертификат PKCS #12 трябва да съдържа поне един сертификат и само един частен ключ.",
-    "Failed to import the certificate. Please check the password." : "Неуспешно импортиране на сертификата. Моля, проверете паролата.",
-    "Certificate imported successfully" : "Успешно импортиране на сертификата",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Неуспешно импортиране на сертификата. Моля, уверете се, че частният ключ съответства на сертификата и не е защитен с парола.",
-    "Failed to import the certificate" : "Неуспешно импортиране на сертификата",
     "Account connected" : "Профилът е свързан",
     "You can close this window" : "Можете да затворите този прозорец",
     "Connect your mail account" : "Свързване към ваш имейл профил",
@@ -557,8 +558,7 @@ OC.L10N.register(
     "The link leads to %s" : "Връзката води до %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желаете да посетите тази страница, може да се върнете към <a href=\"%s\">Поща</a>.",
     "Continue to %s" : "Продължи към %s",
-    "Sieve filter rules" : "Правила за филтриране чрез сито",
-    "Sieve filter server" : "Сървър за сито филтър",
-    "Unselect" : "Размаркирай"
+    "Uploading attachments …" : "Качване на прикачените файлове ...",
+    "Sending …" : "Изпращане..."
 },
 "nplurals=2; plural=(n != 1);");
