@@ -318,7 +318,8 @@ OC.L10N.register(
     "Decline" : "Odmítnout",
     "Tentatively accept" : "Nezávazně přijmout",
     "More options" : "Další volby",
-    "This event is in the past." : "Tato událost je v minulosti.",
+    "This message has an attached invitation but the invitation dates are in the past" : "Tato zpráva má připojenou pozvánku, ale její datumy se nacházejí v minulosti",
+    "This message has an attached invitation but the invitation does not contain a participant that matches any configured mail account address" : "Tato zpráva má připojenou pozvánku, ale ta neobsahuje účastníka, který by odpovídal některé z adres nastavených e-mailových účtů",
     "Could not remove internal address {sender}" : "Nepodařilo odebrat vnitřní adresu {sender}",
     "Could not add internal address {address}" : "Nebylo možné přidat vnitřní adresu {address}",
     "individual" : "jednotlivé",
@@ -330,6 +331,8 @@ OC.L10N.register(
     "Itinerary for {type} is not supported yet" : "Itinerář {type} zatím ještě není podporován",
     "To archive a message please configure an archive mailbox in account settings" : "Pokud chcete zprávu archivovat, nastavte si v účtu schránku pro archiv",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nejste oprávněni přesunout tuto zprávu do archivní složky a/nebo tuto zprávu smazat ze stávající složky",
+    "Your IMAP server does not support storing the seen/unseen state." : "Vámi využívaný IMAP server nepodporuje ukládání stavu zobrazeno/nezobrazeno.",
+    "Could not mark message as seen/unseen" : "Nebylo možné označit zprávu jako zobrazenou/nezobrazenou",
     "Could not open mailbox" : "Nedaří se otevřít e-mailovou schránku",
     "Loading messages …" : "Načítání zpráv…",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Vytváření rejstříku vašich zpráv. V případě rozsáhlejších e-mailových schránek toto může trvat poněkud déle.",
@@ -389,6 +392,7 @@ OC.L10N.register(
     "Loading …" : "Načítání…",
     "Not supported by the server" : "Nepodporováno serverem",
     "{usage} of {limit} used" : "využito {usage} z {limit}",
+    "Unable to create mailbox. The name likely contains invalid characters. Please try another name." : "Schránku nebylo možné vytvořit. Název nejspíš obsahuje neplatné znaky. Zkuste jiný název.",
     "Remove account" : "Odebrat účet",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Účet pro {email} a data e-mailů, uložených v mezipaměti, budou odebrána z Nextcloud, ale ne z poskytovatele e-mailů.",
     "Remove {email}" : "Odebrat {email}",
@@ -441,12 +445,11 @@ OC.L10N.register(
     "Message discarded" : "Zpráva zahozena",
     "Could not discard message" : "Zprávu se nepodařilo zahodit",
     "Maximize composer" : "Maximalizovat dialog editoru zprávy",
-    "Collapse composer" : "Sbalit editor psaní",
+    "Show recipient details" : "Zobrazit podrobnosti o příjemci",
+    "Hide recipient details" : "Skrýt podrobnosti o příjemci",
     "Minimize composer" : "Minimalizovat dialog psaní",
     "Error sending your message" : "Chyba při odesílání vaší zprávy",
     "Retry" : "Zkusit znovu",
-    "Uploading attachments …" : "Nahrávání příloh…",
-    "Sending …" : "Odesílání…",
     "Warning sending your message" : "Varování při odesílání vaší zprávy",
     "Send anyway" : "Poslat i tak",
     "Welcome to {productName} Mail" : "Vítejte v {productName} Poště",
@@ -769,6 +772,7 @@ OC.L10N.register(
     "Keep editing message" : "Pokračovat v upravování zprávy",
     "Attachments were not copied. Please add them manually." : "Přílohy nebyly zkopírovány. Přidejte je ručně.",
     "Could not create snooze mailbox" : "Nepodařilo se vytvořit schránku pro odložené",
+    "Sending message…" : "Odesílání zprávy…",
     "Message sent" : "Zpráva odeslána",
     "Could not send message" : "Zprávu se nepodařilo odeslat",
     "Message copied to \"Sent\" mailbox" : "Zpráva zkopírována do složky „Odeslané“",
@@ -784,6 +788,9 @@ OC.L10N.register(
     "Redirect" : "Přesměrovat",
     "The link leads to %s" : "Odkaz vede na %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Pokud nechcete tuto stránku navštívit, můžete se vrátit do <a href=\"%s\">e-mailu</a>.",
-    "Continue to %s" : "Pokračovat na %s"
+    "Continue to %s" : "Pokračovat na %s",
+    "Collapse composer" : "Sbalit editor psaní",
+    "Uploading attachments …" : "Nahrávání příloh…",
+    "Sending …" : "Odesílání…"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
