@@ -4,6 +4,9 @@ OC.L10N.register(
     "Work" : "Gwaith",
     "Personal" : "Personol",
     "Mail" : "E-bost",
+    "Connecting" : "Yn cysylltu",
+    "Save" : "Cadw",
+    "Connect" : "Cysylltu",
     "Auto" : "Awto",
     "Name" : "Enw",
     "Password" : "Cyfrinair",
@@ -23,9 +26,6 @@ OC.L10N.register(
     "SMTP Port" : "Porth SMTP",
     "SMTP User" : "Defnyddiwr SMTP",
     "SMTP Password" : "Cyfrinair SMTP",
-    "Connecting" : "Yn cysylltu",
-    "Save" : "Cadw",
-    "Connect" : "Cysylltu",
     "Signature" : "Llofnod",
     "Mail server" : "Gweinydd e-bost",
     "Go back" : "Nôl",
@@ -36,6 +36,7 @@ OC.L10N.register(
     "List" : "Rhestr",
     "Use Gravatar and favicon avatars" : "Defnyddiwch Gravatar ac afatarau favicon",
     "Register" : "Cofrestru",
+    "About" : "Ynglyn â",
     "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
     "Compose new message" : "Ysgrifennu Neges _Newydd",
     "Newer message" : "Neges diweddarach",
@@ -52,8 +53,8 @@ OC.L10N.register(
     "Draft saved" : "Cadwyd y drafft",
     "Upload attachment" : "Llwytho atodiad",
     "Add attachment from Files" : "Ychwanegwch atodiad o'r Ffeiliau",
-    "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
     "Choose" : "Dewisa",
+    "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
     "Confirm" : "Cadarnhau",
     "Draft: " : "Drafft:",
     "Favorite" : "Ffefryn",
@@ -69,6 +70,7 @@ OC.L10N.register(
     "Decline" : "Gwrthod",
     "Remove" : "Gwaredu",
     "Other" : "Arall",
+    "Translate" : "Cyfieithu",
     "Choose a folder to store the attachment in" : "Dewiswch ffolder i gadw'r atodiad ynddi",
     "Import into calendar" : "Mewnforio i'r calendr",
     "Download attachment" : "Llwytho'r atodiad i lawr",
@@ -77,23 +79,21 @@ OC.L10N.register(
     "Save all to Files" : "Cadw'r cyfan i Ffeiliau",
     "The images have been blocked to protect your privacy." : "Mae'r delweddau wedi'u rhwystro i ddiogelu eich preifatrwydd.",
     "Move" : "Symud",
-    "Remove account" : "Dileu cyfrif",
     "Loading …" : "Yn llwytho …",
+    "Remove account" : "Dileu cyfrif",
     "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
     "Rename" : "Ailenwi",
     "New message" : "Neges newydd",
     "Error sending your message" : "Gwall wrth anfon eich neges",
     "Retry" : "Ceisio eto",
-    "Uploading attachments …" : "Llwytho atodiadau ...",
-    "Sending …" : "Anfon",
     "Add" : "Ychwanegu",
     "Close" : "Cau",
     "Date" : "Date",
     "Tags" : "Tagiau",
     "Custom" : "Cyfaddas",
     "Not found" : "Heb ei ganfod",
-    "(organizer)" : "(trefnydd)",
     "Untitled event" : "Digwyddiad di-deitl",
+    "(organizer)" : "(trefnydd)",
     "Actions" : "Gweithredoedd",
     "User" : "User",
     "Certificate" : "Tystysgrif",
@@ -119,6 +119,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Cliciwch yma os na chewch eich ailgyfeirio'n awtomatig o fewn yr ychydig eiliadau nesaf.",
     "Redirect" : "Ailgyfeirio",
     "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
-    "Continue to %s" : "Parhau i %s"
+    "Continue to %s" : "Parhau i %s",
+    "Uploading attachments …" : "Llwytho atodiadau ...",
+    "Sending …" : "Anfon"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
