@@ -253,9 +253,16 @@ OC.L10N.register(
     "Save all to Files" : "Gem alle filer",
     "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte dit privatliv.",
     "Show images" : "Vis billeder",
-    "Quoted text" : "Noteret tekst",
+    "Always show images from {sender}" : "Altid vis billeder fra {sender}",
+    "Always show images from {domain}" : "Altid vis billeder fra {domain}",
+    "Quoted text" : "Citeret tekst",
     "Move" : "Flyt",
+    "Moving" : "Flytter",
+    "Moving thread" : "Flytter tråd",
+    "Moving message" : "Flytter besked",
     "Loading …" : "Indlæser…",
+    "Not supported by the server" : "Ikke understøttet af serveren",
+    "{usage} of {limit} used" : "{usage} af {limit} brugt",
     "Remove account" : "Fjern konto",
     "Remove {email}" : "Fjern {email}",
     "Quota" : "Kvote",
@@ -285,8 +292,6 @@ OC.L10N.register(
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
     "Error sending your message" : "Fejl ved afsendelse af din besked",
     "Retry" : "Prøv igen",
-    "Uploading attachments …" : "Uploader vedhæftninger",
-    "Sending …" : "Sender ...",
     "Warning sending your message" : "Advarsel om at sende din besked",
     "Send anyway" : "Send alligevel",
     "Welcome to {productName} Mail" : "Velkommen til {productName} mail",
@@ -401,6 +406,7 @@ OC.L10N.register(
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
     "Continue to %s" : "Videre til %s",
-    "This event is in the past." : "Denne begivenhed er i fortiden."
+    "Uploading attachments …" : "Uploader vedhæftninger",
+    "Sending …" : "Sender ..."
 },
 "nplurals=2; plural=(n != 1);");
