@@ -278,8 +278,6 @@ OC.L10N.register(
     "Could not discard message" : "Δεν ήταν δυνατή η απόρριψη του μηνύματος",
     "Error sending your message" : "Σφάλμα κατά την αποστολή του μηνύματός σας",
     "Retry" : "Δοκιμή ξανά",
-    "Uploading attachments …" : "Ανέβασμα συνημμένων ...",
-    "Sending …" : "Γίνεται αποστολή...",
     "Send anyway" : "Στείλτε ούτως ή άλλως",
     "Message" : "Μήνυμα",
     "Could not open outbox" : "Αδυναμία ανοίγματος εξερχομένων",
@@ -390,6 +388,7 @@ OC.L10N.register(
     "Redirect" : "Ανακατεύθυνση",
     "The link leads to %s" : "Αυτός ο σύνδεσμος οδηγεί στο %s",
     "Continue to %s" : "Συνέχεια στο %s",
-    "This event is in the past." : "Αυτή η εκδήλωση ανήκει στο παρελθόν."
+    "Uploading attachments …" : "Ανέβασμα συνημμένων ...",
+    "Sending …" : "Γίνεται αποστολή..."
 },
 "nplurals=2; plural=(n != 1);");
