@@ -9,6 +9,10 @@ OC.L10N.register(
     "Mail" : "Retpoŝtilo",
     "Mails" : "Retpoŝtoj",
     "💌 A mail app for Nextcloud" : "Poŝtprogrameto por Nextcloud",
+    "Connecting" : "Konektante",
+    "Save" : "Konservi",
+    "Connect" : "Konekti",
+    "Password required" : "Pasvorto bezonata",
     "Auto" : "Aŭtomate",
     "Name" : "Nomo",
     "Password" : "Pasvorto",
@@ -28,10 +32,6 @@ OC.L10N.register(
     "SMTP Port" : "SMTP-pordo",
     "SMTP User" : "SMTP-uzanto",
     "SMTP Password" : "SMTP-pasvorto",
-    "Connecting" : "Konektante",
-    "Save" : "Konservi",
-    "Connect" : "Konekti",
-    "Password required" : "Pasvorto bezonata",
     "Account settings" : "Kontaj agordoj",
     "Signature" : "Subskribo",
     "A signature is added to the text of new messages and replies." : "Subskribo aldonus al la teksto de novaj mesaĝoj kaj respondoj.",
@@ -73,10 +73,11 @@ OC.L10N.register(
     "Upload attachment" : "Alŝuti kunsendaĵon",
     "Add attachment from Files" : "Aldoni kunsendaĵojn el „Dosieroj“",
     "Enter a date" : "Entajpu daton",
-    "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
     "Choose" : "Elekti",
+    "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
     "Confirm" : "Konfirmi",
     "Plain text" : "Ebenaĵa teksto",
+    "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
     "Draft: " : "Malneto:",
     "Unfavorite" : "Malpliŝatati",
     "Favorite" : "Pliŝatati",
@@ -84,12 +85,11 @@ OC.L10N.register(
     "Edit tags" : "Redakti etikedojn",
     "More actions" : "Pliaj agoj",
     "Back" : "Antaŭen",
-    "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
     "Report this bug" : "Raporti tiun problemon",
+    "Could not create event" : "Ne eblis krei okazaĵon",
     "All day" : "Tuttage",
     "Description" : "Priskribo",
     "Create" : "Krei",
-    "Could not create event" : "Ne eblis krei okazaĵon",
     "Select" : "Elekti",
     "Comment" : "Komento",
     "Accept" : "Akcepti",
@@ -100,40 +100,41 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
     "Other" : "Alia",
     "Forward" : "Antaŭen",
+    "Translate" : "Traduku",
+    "Unnamed" : "Nenomita",
+    "Embedded message" : "Enkorpiga mesaĝo",
     "Choose a folder to store the attachment in" : "Elektu dosierujon en kiu konservi la kunsendaĵon",
     "Import into calendar" : "Importi en kalendaron",
     "Download attachment" : "Elŝuti kunsendaĵon",
     "Save to Files" : "Konservi en „Dosieroj“",
-    "Unnamed" : "Nenomita",
-    "Embedded message" : "Enkorpiga mesaĝo",
     "Choose a folder to store the attachments in" : "Elektu dosierujon en kiu konservi la kunsendaĵojn",
     "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
     "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
     "Move" : "Movi",
+    "Loading …" : "Ŝargas …",
+    "Remove account" : "Forigi konton",
     "Quota" : "Kvoto",
     "Saving" : "Konservado",
     "Move down" : "Movi malsupren",
-    "Remove account" : "Forigi konton",
-    "Loading …" : "Ŝargas …",
+    "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
     "Mark all as read" : "Marki ĉion kiel legita",
     "Rename" : "Alinomi",
     "Clear cache" : "Forviŝi la kaŝmemoron",
-    "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
     "New message" : "Nova mesaĝo",
+    "Reply" : "Respondi",
     "Error sending your message" : "Eraro dum sendo de via mesaĝo",
     "Retry" : "Reprovi",
-    "Uploading attachments …" : "Alŝutas kunsendaĵojn...",
-    "Sending …" : "Sendado...",
-    "Reply" : "Respondi",
     "Message" : "Mesaĝo",
     "Copy to clipboard" : "Kopii tondejen",
     "Add" : "Aldoni",
+    "Show less" : "Montri malpli",
+    "Show more" : "Montri pli",
+    "Clear" : "Viŝi",
     "Close" : "Malfermi",
     "Date" : "Date",
     "Tags" : "Etikedoj",
     "Select tags" : "Elekti etikedojn",
     "Last 7 days" : "Lastaj 7 tagoj",
-    "Clear" : "Viŝi",
     "Custom" : "Propra",
     "Signature …" : "Subskribo …",
     "Save signature" : "Konservi subskribon",
@@ -144,12 +145,12 @@ OC.L10N.register(
     "Untitled event" : "Sentitola okazaĵo",
     "Import into {calendar}" : "Importi en {calendar}",
     "Event imported into {calendar}" : "Okazaĵo importis en {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flugo {flightNr} de {depAirport} al {arrAirport}",
     "Airplane" : "Aviadilo",
     "Reservation {id}" : "Rezervejo {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flugo {flightNr} de {depAirport} al {arrAirport}",
-    "Train" : "Trajno",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} de {depStation} al {arrStation}",
     "Train from {depStation} to {arrStation}" : "Trajno de {depStation} al {arrStation}",
+    "Train" : "Trajno",
     "Actions" : "Agoj",
     "Priority" : "Prioritato",
     "Mail app" : "Retpoŝtprogrameto",
@@ -190,6 +191,7 @@ OC.L10N.register(
     "Redirect" : "Alidirekto",
     "The link leads to %s" : "La ligilo iras al %s",
     "Continue to %s" : "Daŭrigi al %s",
-    "Unselect" : "Malelekti"
+    "Uploading attachments …" : "Alŝutas kunsendaĵojn...",
+    "Sending …" : "Sendado..."
 },
 "nplurals=2; plural=(n != 1);");
