@@ -336,8 +336,6 @@ OC.L10N.register(
     "Minimize composer" : "Minimizar editor",
     "Error sending your message" : "Error al enviar tu mensaje",
     "Retry" : "Reintentar",
-    "Uploading attachments …" : "Subiendo adjuntos...",
-    "Sending …" : "Enviando ...",
     "Warning sending your message" : "Advertencia al enviar tu mensaje",
     "Send anyway" : "Enviar de todos modos",
     "Autoresponder off" : "Respuesta automática desactivada",
@@ -592,6 +590,7 @@ OC.L10N.register(
     "The link leads to %s" : "La liga lleva a %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no deseas visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
     "Continue to %s" : "Continuar a %s",
-    "This event is in the past." : "Este evento está en el pasado."
+    "Uploading attachments …" : "Subiendo adjuntos...",
+    "Sending …" : "Enviando ..."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
