@@ -17,6 +17,10 @@ OC.L10N.register(
     "Drafts are saved in:" : "Skice se spremaju u:",
     "Sent messages are saved in:" : "Poslane poruke spremaju se u:",
     "Deleted messages are moved in:" : "Izbrisane poruke spremaju se u:",
+    "Connecting" : "Povezivanje",
+    "Save" : "Spremi",
+    "Connect" : "Poveži",
+    "Password required" : "Potrebna zaporka",
     "Auto" : "Auto",
     "Name" : "Naziv",
     "Mail address" : "Email adresa",
@@ -37,10 +41,6 @@ OC.L10N.register(
     "SMTP Port" : "SMTP port",
     "SMTP User" : "SMTP korisničko ime",
     "SMTP Password" : "SMTP zaporka",
-    "Connecting" : "Povezivanje",
-    "Save" : "Spremi",
-    "Connect" : "Poveži",
-    "Password required" : "Potrebna zaporka",
     "Account settings" : "Postavke računa",
     "Aliases" : "Pseudonimi",
     "Signature" : "Potpis",
@@ -58,6 +58,8 @@ OC.L10N.register(
     "Add alias" : "Dodaj pseudonim",
     "Create alias" : "Stvori pseudonim",
     "Cancel" : "Odustani",
+    "Put my text to the bottom of a reply instead of on top of it." : "Stavite tekst na dno odgovora umjesto na vrh.",
+    "Could not update preference" : "Ažuriranje postavki nije uspjelo",
     "Accounts" : "Korisnićki računi",
     "Add mail account" : "Dodaj račun e-pošte",
     "General" : "Općenito",
@@ -68,6 +70,7 @@ OC.L10N.register(
     "Register" : "Registriraj se",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
     "Trusted senders" : "Pouzdani pošiljatelji",
+    "About" : "Informacije",
     "Keyboard shortcuts" : "Tipkovni prečaci",
     "Compose new message" : "Sastavi novu poruku",
     "Newer message" : "Novija poruka",
@@ -79,8 +82,7 @@ OC.L10N.register(
     "Search" : "Traži",
     "Send" : "Pošalji",
     "Refresh" : "Osvježi",
-    "Put my text to the bottom of a reply instead of on top of it." : "Stavite tekst na dno odgovora umjesto na vrh.",
-    "Could not update preference" : "Ažuriranje postavki nije uspjelo",
+    "Message {id} could not be found" : "Poruka {id} nije pronađena",
     "From" : "Od",
     "Select account" : "Odaberi račun",
     "To" : "Do",
@@ -100,15 +102,17 @@ OC.L10N.register(
     "Request a read receipt" : "Zatražite potvrdu o čitanju",
     "Encrypt message with Mailvelope" : "Šifriraj poruku s Mailvelope",
     "Enter a date" : "Unesi datum",
-    "Message {id} could not be found" : "Poruka {id} nije pronađena",
+    "Choose" : "Odaberite",
     "Choose a file to add as attachment" : "Izaberi datoteku kao privitak",
     "Choose a file to share as a link" : "Izaberi datoteku za dijeljenje putem poveznice",
-    "Choose" : "Odaberite",
     "Confirm" : "Potvrdi",
     "Plain text" : "Običan tekst",
     "Rich text" : "Bogat tekst",
     "No messages in this mailbox" : "Nema poruka u ovom sandučiću",
     "No messages" : "Nema poruka",
+    "Blind copy recipients only" : "Samo primatelji skrivenih kopija poruke",
+    "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
+    "Could not delete message" : "Brisanje poruke nije uspjelo",
     "Draft: " : "Skica: ",
     "Unfavorite" : "Ukloni iz favorita",
     "Favorite" : "Favorit",
@@ -123,9 +127,6 @@ OC.L10N.register(
     "Edit as new message" : "Uredi kao novu poruku",
     "Create event" : "Stvori događaj",
     "Create task" : "Stvori zadatak",
-    "Blind copy recipients only" : "Samo primatelji skrivenih kopija poruke",
-    "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
-    "Could not delete message" : "Brisanje poruke nije uspjelo",
     "Load more" : "Učitaj više",
     "_Mark {number} read_::_Mark {number} read_" : ["Označi {number} kao pročitano","Označi {number} kao pročitano","Označi {number} kao pročitano"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Označi {number} kao nepročitano","Označi {number} kao nepročitano","Označi {number} kao nepročitano"],
@@ -137,43 +138,44 @@ OC.L10N.register(
     "_Move {number} thread_::_Move {number} threads_" : ["Premjesti {number} dretvu","Premjesti {number} dretve","Premjesti {number} dretvi"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Proslijedi {number} kao privitak","Proslijedi {number} kao privitak","Proslijedi {number} kao privitak"],
     "Report this bug" : "Prijavi ovu pogrešku",
+    "Event created" : "Događaj je stvoren",
+    "Could not create event" : "Nije moguće stvoriti događaj",
     "All day" : "Cijeli dan",
     "Description" : "Opis",
     "Create" : "Stvori",
-    "Event created" : "Događaj je stvoren",
-    "Could not create event" : "Nije moguće stvoriti događaj",
     "Select" : "Odaberi",
     "Comment" : "Komentar",
     "Accept" : "Prihvati",
     "Decline" : "Odbij",
     "More options" : "Više mogućnosti",
+    "individual" : "pojedinac",
     "domain" : "domena",
     "Remove" : "Ukloni",
     "email" : "e-pošta",
-    "individual" : "pojedinac",
     "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
     "Could not open mailbox" : "Nije moguće otvoriti sandučić",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksiranje poruka u tijeku. Ova radnja može potrajati za veće sandučiće.",
     "Choose target mailbox" : "Odaberi ciljni sandučić",
     "No more submailboxes in here" : "Ovdje više nema podsandučića",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Poruke se automatski označavaju kao važne na temelju poruka kojima ste rukovali ili koje ste označili kao važne. U početku ćete možda morati ručno mijenjati važnost poruka kako bi sustav zapamtio vaše želje, ali s vremenom će se poboljšati.",
     "Important info" : "Važne informacije",
     "Other" : "Ostalo",
-    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Poruke se automatski označavaju kao važne na temelju poruka kojima ste rukovali ili koje ste označili kao važne. U početku ćete možda morati ručno mijenjati važnost poruka kako bi sustav zapamtio vaše želje, ali s vremenom će se poboljšati.",
+    "Could not send mdn" : "Nije moguće poslati mdn",
     "The sender of this message has asked to be notified when you read this message." : "Pošiljatelj ove poruke zatražio je da bude obaviješten kad pročitate ovu poruku.",
     "Notify the sender" : "Obavijestite pošiljatelja",
     "You sent a read confirmation to the sender of this message." : "Poslali ste potvrdu o čitanju pošiljatelju ove poruke.",
-    "Could not send mdn" : "Nije moguće poslati mdn",
     "Forward" : "Naprijed",
     "Move message" : "Premjesti poruku",
+    "Translate" : "Prevedi",
     "View source" : "Vidi izvor",
     "Download thread data for debugging" : "Preuzmi podatke o dretvi radi otklanjanje pogrešaka",
     "Message body" : "Tijelo poruke",
+    "Unnamed" : "Neimenovano",
+    "Embedded message" : "Ugrađena poruka",
     "Choose a folder to store the attachment in" : "Izaberi mapu za spremanje privitka",
     "Import into calendar" : "Dodaj u kalendar",
     "Download attachment" : "Preuzmi privitak",
     "Save to Files" : "Spremi u datoteke",
-    "Unnamed" : "Neimenovano",
-    "Embedded message" : "Ugrađena poruka",
     "Choose a folder to store the attachments in" : "Izaberi mapu za spremanje privitaka",
     "Save all to Files" : "Spremi sve u datoteke",
     "Download Zip" : "Preuzmi Zip",
@@ -189,21 +191,27 @@ OC.L10N.register(
     "Moving" : "Premještanje",
     "Moving thread" : "Premještanje dretve",
     "Moving message" : "Premještanje poruke",
+    "Loading …" : "Učitavanje…",
+    "Not supported by the server" : "Ne podržava poslužitelj",
+    "{usage} of {limit} used" : "{usage} od {limit} iskorišteno",
+    "Remove account" : "Izbriši račun",
+    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} i podaci e-pošte spremljeni u predmemoriji uklonit će se iz Nextclouda, ali ne iz vašeg davatelja usluga e-pošte.",
+    "Remove {email}" : "Ukloni {email}",
     "Quota" : "Kvota",
     "Show only subscribed mailboxes" : "Prikaži samo pretplaćene sandučiće",
     "Add mailbox" : "Dodaj sandučić",
     "Saving" : "Spremanje",
     "Move up" : "Premjesti gore",
     "Move down" : "Premjesti dolje",
-    "Remove account" : "Izbriši račun",
-    "Loading …" : "Učitavanje…",
-    "Not supported by the server" : "Ne podržava poslužitelj",
-    "{usage} of {limit} used" : "{usage} od {limit} iskorišteno",
-    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} i podaci e-pošte spremljeni u predmemoriji uklonit će se iz Nextclouda, ali ne iz vašeg davatelja usluga e-pošte.",
-    "Remove {email}" : "Ukloni {email}",
     "Show all subscribed mailboxes" : "Prikaži sve pretplaćene sandučiće",
     "Show all mailboxes" : "Prikaži sve sandučiće",
     "Collapse mailboxes" : "Sakrij sandučiće",
+    "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepročitana od {total}","{unread} nepročitane od {total}","{unread} nepročitanih od {total}"],
+    "The mailbox and all messages in it will be deleted." : "Izbrisat će se sandučić i sve pripadajuće poruke.",
+    "Delete mailbox" : "Izbriši sandučić",
+    "Delete mailbox {name}" : "Izbriši sandučić {name}",
+    "An error occurred, unable to rename the mailbox." : "Došlo je do pogreške, nije moguće promijeniti naziv sandučića.",
     "Mark all as read" : "Označi sve kao pročitano",
     "Mark all messages of this mailbox as read" : "Označi sve poruke u ovom sandučiću kao pročitane",
     "Add submailbox" : "Dodaj podsandučić",
@@ -212,21 +220,14 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Izbrišite podatke iz lokalnog međuspremnika u slučaju da postoje problemi sa sinkronizacijom.",
     "Subscribed" : "Pretplaćen",
     "Sync in background" : "Sinkronizacija u pozadini",
-    "Delete mailbox" : "Izbriši sandučić",
-    "The mailbox and all messages in it will be deleted." : "Izbrisat će se sandučić i sve pripadajuće poruke.",
-    "Delete mailbox {name}" : "Izbriši sandučić {name}",
-    "An error occurred, unable to rename the mailbox." : "Došlo je do pogreške, nije moguće promijeniti naziv sandučića.",
-    "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
     "New message" : "Nova poruka",
-    "Error sending your message" : "Pogreška pri slanju poruke",
-    "Retry" : "Pokušaj ponovno",
-    "Uploading attachments …" : "Otpremanje privitaka...",
-    "Sending …" : "Slanje…",
-    "Warning sending your message" : "Upozorenje pri slanju poruke",
-    "Send anyway" : "Svejedno pošalji",
     "Reply" : "Odgovori",
     "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Pokušavate poslati poruku velikom broju primatelja koji su navedeni u poljima Za i/ili Cc. Razmislite o korištenju polja Bcc kako adrese primatelja ne bi bile vidljive.",
+    "Error sending your message" : "Pogreška pri slanju poruke",
+    "Retry" : "Pokušaj ponovno",
+    "Warning sending your message" : "Upozorenje pri slanju poruke",
+    "Send anyway" : "Svejedno pošalji",
     "Message" : "Poruka",
     "Oh Snap!" : "Oh Snap!",
     "Contacts with this address" : "Kontakti s ovom adresom",
@@ -235,12 +236,14 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiraj u međuspremnik",
     "Contact name …" : "Naziv kontakta…",
     "Add" : "Dodaj",
+    "Show less" : "Prikaži manje",
+    "Show more" : "Prikaži više",
+    "Clear" : "Izbriši",
     "Close" : "Zatvori",
     "Body" : "Tijelo",
     "Date" : "Datum",
     "Tags" : "Oznake",
     "Select tags" : "Odaberite oznake",
-    "Clear" : "Izbriši",
     "Sieve Port" : "Sieve port",
     "Custom" : "Prilagođeno",
     "Sieve User" : "Sieve korisnik",
@@ -250,36 +253,44 @@ OC.L10N.register(
     "Signature …" : "Potpis...",
     "Save signature" : "Spremi potpis",
     "Place signature above quoted text" : "Stavi potpis iznad citiranog teksta",
+    "An error occurred, unable to rename the tag." : "Došlo je do pogreške, nije moguće promijeniti naziv oznake.",
     "Saving new tag name …" : "Spremanje novog naziva oznake…",
     "Delete tag" : "Izbriši oznaku",
-    "An error occurred, unable to rename the tag." : "Došlo je do pogreške, nije moguće promijeniti naziv oznake.",
+    "Tag already exists" : "Oznaka već postoji",
+    "An error occurred, unable to create the tag." : "Došlo je do pogreške, nije moguće stvoriti oznaku.",
     "Add default tags" : "Dodaj zadane oznake",
     "Add tag" : "Dodaj oznaku",
     "Saving tag …" : "Spremanje oznake...",
-    "Tag already exists" : "Oznaka već postoji",
-    "An error occurred, unable to create the tag." : "Došlo je do pogreške, nije moguće stvoriti oznaku.",
-    "Not found" : "Nije pronađeno",
     "Could not load your message thread" : "Učitavanje vaše dretve poruka nije uspjelo",
+    "Not found" : "Nije pronađeno",
     "Unsubscribe" : "Otkaži pretplatu",
     "Reply to sender only" : "Odgovori pošiljatelju",
     "Mark as unread" : "Označi kao nepročitano",
     "Mark as read" : "Označi kao pročitano",
     "Delete message" : "Izbriši poruku",
     "Message source" : "Izvor poruke",
-    "No senders are trusted at the moment." : "Trenutno nema pouzdanih pošiljatelja.",
     "Could not remove trusted sender {sender}" : "Nije moguće ukloniti pouzdanog pošiljatelja {sender}",
-    "(organizer)" : "(organizator)",
+    "No senders are trusted at the moment." : "Trenutno nema pouzdanih pošiljatelja.",
     "Untitled event" : "Događaj bez naslova",
+    "(organizer)" : "(organizator)",
     "Import into {calendar}" : "Uvezi u {calendar}",
     "Event imported into {calendar}" : "Događaj je uvezen u {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Let {flightNr} iz {depAirport} do {arrAirport}",
     "Airplane" : "Zrakoplov",
     "Reservation {id}" : "Rezervacija {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Let {flightNr} iz {depAirport} do {arrAirport}",
-    "Train" : "Vlak",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} do {arrStation}",
     "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} do {arrStation}",
+    "Train" : "Vlak",
     "Actions" : "Radnje",
     "Priority" : "Prioritet",
+    "Successfully updated config for \"{domain}\"" : "Konfiguracija za „{domain}“ je uspješno ažurirana",
+    "Error saving config" : "Pogreška pri spremanju konfiguracije",
+    "Saved config for \"{domain}\"" : "Konfiguracija za „{domain}“ je spremljena",
+    "Could not save provisioning setting" : "Spremanje postavke dodjeljivanja nije uspjelo",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Dodjeljivanje je uspješno izvedeno za {count} račun.","Dodjeljivanje je uspješno izvedeno za {count} računa.","Dodjeljivanje je uspješno izvedeno za {count} računa."],
+    "There was an error when provisioning accounts." : "Došlo je do pogreške pri dodjeljivanju računa.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Računima za „{domain}“ je ukinuto dodjeljivanje i izbrisani su",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Pogreška pri brisanju i ukidanju dodjele računa za „{domain}“",
     "Mail app" : "Aplikacija za upravljanje e-poštom",
     "The mail app allows users to read mails on their IMAP accounts." : "Aplikacija za upravljanje e-poštom omogućuje korisnicima da čitaju svoje poruke s IMAP računa.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Ovdje možete pronaći postavke za čitavu instancu. Postavke za pojedinog korisnika nalaze se u samoj aplikaciji (donji lijevi kut).",
@@ -298,14 +309,10 @@ OC.L10N.register(
     "Anti Spam Service" : "Usluga za sprječavanje neželjene pošte",
     "You can set up an anti spam service email address here." : "Ovdje možete postaviti adresu e-pošte za uslugu sprječavanja neželjene pošte.",
     "Any email that is marked as spam will be sent to the anti spam service." : "Svaka poruka e-pošte koja je označena kao neželjena pošta šalje se usluzi za sprječavanje neželjene pošte.",
-    "Successfully updated config for \"{domain}\"" : "Konfiguracija za „{domain}“ je uspješno ažurirana",
-    "Error saving config" : "Pogreška pri spremanju konfiguracije",
-    "Saved config for \"{domain}\"" : "Konfiguracija za „{domain}“ je spremljena",
-    "Could not save provisioning setting" : "Spremanje postavke dodjeljivanja nije uspjelo",
-    "There was an error when provisioning accounts." : "Došlo je do pogreške pri dodjeljivanju računa.",
-    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Računima za „{domain}“ je ukinuto dodjeljivanje i izbrisani su",
-    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Pogreška pri brisanju i ukidanju dodjele računa za „{domain}“",
-    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Dodjeljivanje je uspješno izvedeno za {count} račun.","Dodjeljivanje je uspješno izvedeno za {count} računa.","Dodjeljivanje je uspješno izvedeno za {count} računa."],
+    "Successfully set up anti spam email addresses" : "Uspješno postavljene adrese e-pošte za sprječavanje neželjene pošte",
+    "Error saving anti spam email addresses" : "Pogreška pri spremanju adresa e-pošte za sprječavanje neželjene pošte",
+    "Successfully deleted anti spam reporting email" : "Uspješno izbrisana adresa e-pošte za prijavu neželjene pošte",
+    "Error deleting anti spam reporting email" : "Pogreška pri brisanju adrese e-pošte za prijavu neželjene pošte",
     "Anti Spam" : "Sprječavanje neželjene pošte",
     "Add the email address of your anti spam report service here." : "Ovdje dodajte adresu e-pošte svoje usluge za prijavljivanje neželjene pošte.",
     "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Kada upotrebljavate ovu postavku, poruka e-pošte s prijavom šalje se poslužitelju za prijavu neželjene pošte kada korisnik klikne na „Označi kao neželjenu poštu”.",
@@ -313,10 +320,6 @@ OC.L10N.register(
     "\"Mark as Spam\" Email Address" : "Adresa e-pošte „Označi kao neželjenu poštu”",
     "\"Mark Not Junk\" Email Address" : "Adresa e-pošte „Označi da nije neželjena pošta”",
     "Reset" : "Resetiraj",
-    "Successfully set up anti spam email addresses" : "Uspješno postavljene adrese e-pošte za sprječavanje neželjene pošte",
-    "Error saving anti spam email addresses" : "Pogreška pri spremanju adresa e-pošte za sprječavanje neželjene pošte",
-    "Successfully deleted anti spam reporting email" : "Uspješno izbrisana adresa e-pošte za prijavu neželjene pošte",
-    "Error deleting anti spam reporting email" : "Pogreška pri brisanju adrese e-pošte za prijavu neželjene pošte",
     "Client ID" : "ID klijenta",
     "Client secret" : "Tajni ključ klijenta",
     "Domain Match: {provisioningDomain}" : "Podudaranje domene: {provisioningDomain}",
@@ -375,8 +378,7 @@ OC.L10N.register(
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
     "Continue to %s" : "Idi do %s",
-    "Sieve filter rules" : "Pravila filtra Sieve",
-    "Sieve filter server" : "Poslužitelj filtra Sieve",
-    "Unselect" : "Poništi odabir"
+    "Uploading attachments …" : "Otpremanje privitaka...",
+    "Sending …" : "Slanje…"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
