@@ -5,11 +5,11 @@ OC.L10N.register(
     "Work" : "ធ្វើការ",
     "Personal" : "ផ្ទាល់​ខ្លួន",
     "Mail" : "សំបុត្រ",
+    "Save" : "រក្សាទុក",
+    "Connect" : "ភ្ជាប់",
     "Name" : "ឈ្មោះ",
     "Password" : "ពាក្យសម្ងាត់",
     "None" : "គ្មាន",
-    "Save" : "រក្សាទុក",
-    "Connect" : "ភ្ជាប់",
     "Cancel" : "បោះបង់",
     "General" : "ទូទៅ",
     "Delete" : "លុប",
@@ -25,7 +25,6 @@ OC.L10N.register(
     "Other" : "ផ្សេងៗ",
     "Move" : "Move",
     "Rename" : "ប្ដូរ​ឈ្មោះ",
-    "Sending …" : "កំពុង​ផ្ញើរ...",
     "Reply" : "ឆ្លើយតប",
     "Add" : "បញ្ចូល",
     "Close" : "បិទ",
@@ -40,6 +39,7 @@ OC.L10N.register(
     "Inbox" : "ក្នុង​ប្រអប់សារ",
     "Junk" : "ព្រៃ",
     "Sent" : "ផ្ញើ",
-    "Trash" : "ធុង​សំរាម"
+    "Trash" : "ធុង​សំរាម",
+    "Sending …" : "កំពុង​ផ្ញើរ..."
 },
 "nplurals=1; plural=0;");
