@@ -5,6 +5,9 @@ OC.L10N.register(
     "Personal" : "Хувийн",
     "Later" : "Хойшлуулах",
     "Mail" : "шуудан",
+    "Connecting" : "холбож байгаа",
+    "Save" : "Хадгалах",
+    "Connect" : "холбох",
     "Name" : "нэр",
     "Mail address" : "шуудангийн хаяг",
     "Password" : "нууц үг",
@@ -16,9 +19,6 @@ OC.L10N.register(
     "SMTP Port" : "Энгийн мэйл дамжуулах протокол-ийн порт",
     "SMTP User" : "Энгийн мэйл дамжуулах протокол-ийн хэрэглэгч",
     "SMTP Password" : "Энгийн мэйл дамжуулах протокол-ийн нууц үг",
-    "Connecting" : "холбож байгаа",
-    "Save" : "Хадгалах",
-    "Connect" : "холбох",
     "Signature" : "Гарын үсэг",
     "Go back" : "Буцах",
     "Cancel" : "болиулах",
@@ -47,21 +47,21 @@ OC.L10N.register(
     "email" : "цахим шуудан",
     "Other" : "Бусад",
     "Forward" : "дамжих",
+    "Translate" : "Орчуулга",
     "Choose a folder to store the attachment in" : "-д хавсралт хадгалах фолдер сонгоно уу",
     "Download attachment" : "Татаж авах хавсралт",
     "Save to Files" : "Файлд хадгална",
     "Save all to Files" : "бүх файлыг хадгалах",
     "The images have been blocked to protect your privacy." : " таны хувийн нууцыг хамгаалахын тулд дүрсийг хаасан байна.",
     "Move" : "Зөөх",
+    "Loading …" : "Уншиж байна...",
+    "Remove account" : "Аккаунт устгах",
     "Quota" : " хувь хэмжээ",
     "Saving" : "хадгаламж",
-    "Remove account" : "Аккаунт устгах",
-    "Loading …" : "Уншиж байна...",
     "Rename" : "Нэрлэнэ үү",
     "New message" : "шинэ зурвас",
-    "Retry" : "Дахин оролдох",
-    "Sending …" : "илгээмж",
     "Reply" : "хариулт",
+    "Retry" : "Дахин оролдох",
     "Add" : "нэмэх",
     "Date" : "Он сар өдөр",
     "Tags" : "Tag-үүд",
@@ -82,6 +82,7 @@ OC.L10N.register(
     "Junk" : "хэрэггүй",
     "Sent" : "илгээсэн",
     "Trash" : "хог",
-    "Error loading message" : "алдаатай ачааллах зурвас"
+    "Error loading message" : "алдаатай ачааллах зурвас",
+    "Sending …" : "илгээмж"
 },
 "nplurals=2; plural=(n != 1);");
