@@ -158,8 +158,6 @@ OC.L10N.register(
     "Reply" : "Resposta",
     "Error sending your message" : "Erro ao enviar a sua mensagem",
     "Retry" : "Repetir",
-    "Uploading attachments …" : "A enviar anexos ...",
-    "Sending …" : "A enviar...",
     "Warning sending your message" : "Aviso ao enviar a sua mensagem",
     "Send anyway" : "Enviar de qualquer maneira",
     "Message" : "Mensagem",
@@ -229,6 +227,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redirecionado dentro de segundos.",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "A ligação aponta para %s",
-    "Continue to %s" : "Continuar para %s"
+    "Continue to %s" : "Continuar para %s",
+    "Uploading attachments …" : "A enviar anexos ...",
+    "Sending …" : "A enviar..."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
