@@ -5,14 +5,15 @@ OC.L10N.register(
     "Personal" : "පුද්ගලික",
     "Later" : "පසුව",
     "Mail" : "තැපෑල",
-    "Name" : "නම",
-    "Password" : "මුර පදය",
     "Save" : "සුරකින්න",
     "Connect" : "සම්බන්ධ කරන්න",
+    "Name" : "නම",
+    "Password" : "මුර පදය",
     "Signature" : "අත්සන",
     "Go back" : "ආපසු යන්න",
     "Cancel" : "අවලංගු කරන්න",
     "General" : "සමාන්‍යය",
+    "About" : "පිළිබඳ",
     "Archive" : "සංරක්ෂණය",
     "Search" : "සොයන්න",
     "Send" : "යවන්න",
@@ -29,13 +30,15 @@ OC.L10N.register(
     "Decline" : "ප්‍රතික්ෂේප",
     "Remove" : "ඉවත් කරන්න",
     "Other" : "වෙනත්",
-    "Remove account" : "ගිණුම ඉවත් කරන්න",
+    "Translate" : "පරිවර්තනය",
     "Loading …" : "පූරණය වෙමින් …",
+    "Remove account" : "ගිණුම ඉවත් කරන්න",
     "Mark all as read" : "සියල්ල කියවූ ලෙස සලකුණු කරන්න",
-    "Retry" : "නැවත උත්සාහ කරන්න",
     "Reply" : "පිළිතුර",
+    "Retry" : "නැවත උත්සාහ කරන්න",
     "Message" : "පණිවිඩය",
     "Add" : "එකතු කරන්න",
+    "Show more" : "තව පෙන්වන්න",
     "Close" : "වසන්න",
     "Body" : "අන්තර්ගතය",
     "Date" : "දිනය",
