@@ -17,6 +17,9 @@ OC.L10N.register(
     "Drafts are saved in:" : "Thư nháp được lưu trong:",
     "Sent messages are saved in:" : "Tin nhắn đã gửi được lưu trong:",
     "Deleted messages are moved in:" : "Tin nhẵn đã xóa được chuyển tới:",
+    "Save" : "Lưu",
+    "Connect" : "Kết nối",
+    "Password required" : "Mật khẩu đã được yêu cầu",
     "Auto" : "Tự động",
     "Name" : "Tên",
     "Password" : "Mật khẩu",
@@ -32,9 +35,6 @@ OC.L10N.register(
     "SMTP Port" : "Cổng SMTP",
     "SMTP User" : "Người dùng SMTP",
     "SMTP Password" : "Mật khẩu SMTP",
-    "Save" : "Lưu",
-    "Connect" : "Kết nối",
-    "Password required" : "Mật khẩu đã được yêu cầu",
     "Account settings" : "Cài đặt tài khoản",
     "Signature" : "Chữ ký",
     "A signature is added to the text of new messages and replies." : "Chữ ký được thêm vào tin nhắn và thư trả lời mới.",
@@ -47,6 +47,7 @@ OC.L10N.register(
     "Email address" : "Địa chỉ thư điện tử",
     "Add alias" : "Thêm bí danh",
     "Cancel" : "Hủy bỏ",
+    "Put my text to the bottom of a reply instead of on top of it." : "Đặt văn bản ở cuối thư trả lời thay vì ở đầu thư.",
     "Accounts" : "Tài khoản",
     "Add mail account" : "Thêm tài khoản mail",
     "General" : "Tổng hợp",
@@ -56,6 +57,7 @@ OC.L10N.register(
     "Register" : "Đăng ký",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Cho phép ứng dụng thu thập dữ liệu về các tương tác của bạn. Dựa trên dữ liệu này, ứng dụng sẽ điều chỉnh theo sở thích của bạn. Dữ liệu sẽ chỉ được lưu trữ trên máy của bạn.",
     "Trusted senders" : "Người gửi đáng tin cậy",
+    "About" : "Giới thiệu",
     "Keyboard shortcuts" : "Phím tắt",
     "Compose new message" : "Soạn tin nhăn mơi",
     "Newer message" : "Tin nhắn mới hơn",
@@ -67,7 +69,7 @@ OC.L10N.register(
     "Search" : "Tìm",
     "Send" : "Gởi",
     "Refresh" : "Làm mới",
-    "Put my text to the bottom of a reply instead of on top of it." : "Đặt văn bản ở cuối thư trả lời thay vì ở đầu thư.",
+    "Message {id} could not be found" : "Không tìm thấy tin nhắn {id}",
     "From" : "Từ",
     "Select account" : "Chọn tài khoản",
     "To" : "Tới",
@@ -85,13 +87,19 @@ OC.L10N.register(
     "Request a read receipt" : "Yêu cầu xác nhận đã đọc",
     "Encrypt message with Mailvelope" : "Mã hóa thư bằng Mailvelope",
     "Enter a date" : "Nhập ngày",
-    "Message {id} could not be found" : "Không tìm thấy tin nhắn {id}",
+    "Choose" : "Chọn",
     "Choose a file to add as attachment" : "Chọn một tệp để thêm dưới dạng tệp đính kèm",
     "Choose a file to share as a link" : "Chọn một tệp để chia sẻ dưới dạng liên kết",
-    "Choose" : "Chọn",
     "Confirm" : "Xác nhận",
     "No messages in this mailbox" : "Không có thư nào trong hộp thư này",
     "No messages" : "Không có tin nhắn",
+    "Blind copy recipients only" : "Chỉ người nhận bản sao ẩn",
+    "Later today – {timeLocale}" : "Sau này - {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Ngày mai - {timeLocale}",
+    "This weekend – {timeLocale}" : "Cuối tuần này - {timeLocale}",
+    "Next week – {timeLocale}" : "Tuần sau - {timeLocale}",
+    "No trash mailbox configured" : "Không có hộp thư thùng rác nào được định cấu hình",
+    "Could not delete message" : "Không thể xóa tin nhắn",
     "Draft: " : "Bản nháp: ",
     "Favorite" : "Ưa thích",
     "Read" : "Đọc",
@@ -102,9 +110,6 @@ OC.L10N.register(
     "Back" : "Quay lại",
     "Edit as new message" : "Chỉnh sửa dưới dạng tin nhắn mới",
     "Create event" : "Tạo sự kiện mới",
-    "Blind copy recipients only" : "Chỉ người nhận bản sao ẩn",
-    "No trash mailbox configured" : "Không có hộp thư thùng rác nào được định cấu hình",
-    "Could not delete message" : "Không thể xóa tin nhắn",
     "Load more" : "Tải thêm",
     "_Mark {number} read_::_Mark {number} read_" : ["Đánh dấu {number} đã đọc"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Đánh dấu {number} là chưa đọc"],
@@ -113,40 +118,41 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Bỏ chọn {number}"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Chuyển tiếp {number} dưới dạng tệp đính kèm"],
     "Report this bug" : "Báo cáo lỗi này",
+    "Could not create event" : "Không thể tạo sự kiện",
     "All day" : "Cả ngày",
     "Description" : "Mô tả",
     "Create" : "‎Tạo‎",
-    "Could not create event" : "Không thể tạo sự kiện",
     "Select" : "Select",
     "Comment" : "Bình luận",
     "Accept" : "Đồng ý",
     "Decline" : "Từ chối",
+    "individual" : "Cá nhận",
     "domain" : "Miền",
     "Remove" : "Xóa",
     "email" : "Thư điện tử",
-    "individual" : "Cá nhận",
     "Itinerary for {type} is not supported yet" : "Hành trình cho {type} chưa được hỗ trợ",
     "Could not open mailbox" : "Không thể mở hộp thư",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Lập chỉ mục tin nhắn của bạn. Quá trình này có thể lâu hơn một chút đối với các hộp thư lớn.",
     "Choose target mailbox" : "Chọn hộp thư mục tiêu",
     "No more submailboxes in here" : "Không còn hộp thư con nào ở đây",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Tin nhắn sẽ tự động được đánh dấu là quan trọng dựa trên những tin nhắn bạn đã tương tác hoặc được đánh dấu là quan trọng. Lúc đầu, bạn có thể phải thay đổi thủ công tầm quan trọng để dạy hệ thống, nhưng nó sẽ cải thiện theo thời gian.",
     "Important info" : "Thông tin quan trọng",
     "Other" : "Khác",
-    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Tin nhắn sẽ tự động được đánh dấu là quan trọng dựa trên những tin nhắn bạn đã tương tác hoặc được đánh dấu là quan trọng. Lúc đầu, bạn có thể phải thay đổi thủ công tầm quan trọng để dạy hệ thống, nhưng nó sẽ cải thiện theo thời gian.",
+    "Could not send mdn" : "Không thể gửi mdn",
     "The sender of this message has asked to be notified when you read this message." : "Người gửi tin nhắn này đã yêu cầu được thông báo khi bạn đọc tin nhắn này.",
     "Notify the sender" : "Thông báo cho người gửi",
     "You sent a read confirmation to the sender of this message." : "Bạn đã gửi xác nhận đã đọc cho người gửi tin nhắn này.",
-    "Could not send mdn" : "Không thể gửi mdn",
     "Forward" : "Chuyển tiếp",
+    "Translate" : "Dịch",
     "View source" : "Xem nguồn",
     "Download thread data for debugging" : "Tải xuống dữ liệu chuỗi để gỡ lỗi",
     "Message body" : "Nội dung thư",
+    "Unnamed" : "Vô danh",
+    "Embedded message" : "Tin nhắn đã đính kém",
     "Choose a folder to store the attachment in" : "Chọn một thư mục để lưu trữ tệp đính kèm trong",
     "Import into calendar" : "Nhập vào lịch",
     "Download attachment" : "Tải xuống Tệp đính kèm",
     "Save to Files" : "Lưu vào Tệp",
-    "Unnamed" : "Vô danh",
-    "Embedded message" : "Tin nhắn đã đính kém",
     "Choose a folder to store the attachments in" : "Chọn một thư mục để lưu trữ các tệp đính kèm trong",
     "Save all to Files" : "Lưu tất cả vào Tệp",
     "Download Zip" : "Tải xuống định dạng Zip",
@@ -159,21 +165,27 @@ OC.L10N.register(
     "Quoted text" : "Văn bản được trích dẫn",
     "Move" : "Dịch chuyển",
     "Moving" : "Di chuyển",
+    "Loading …" : "Đang tải...",
+    "Not supported by the server" : "Không được máy chủ hỗ trợ",
+    "{usage} of {limit} used" : "Đã sử dụng {use} trong tổng số {limit}",
+    "Remove account" : "Xóa tài khoản",
+    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tài khoản cho {email} và dữ liệu email đã lưu trong bộ nhớ cache sẽ bị xóa khỏi vWorkspace, nhưng không bị xóa khỏi nhà cung cấp dịch vụ email của bạn.",
+    "Remove {email}" : "Xóa {email}",
     "Quota" : "Hạn ngạch",
     "Show only subscribed mailboxes" : "Chỉ hiển thị các hộp thư đã đăng ký",
     "Add mailbox" : "Thêm hộp thư",
     "Saving" : "Tiết kiệm",
     "Move up" : "Di chuyển lên",
     "Move down" : "Di chuyển xuống",
-    "Remove account" : "Xóa tài khoản",
-    "Loading …" : "Đang tải...",
-    "Not supported by the server" : "Không được máy chủ hỗ trợ",
-    "{usage} of {limit} used" : "Đã sử dụng {use} trong tổng số {limit}",
-    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tài khoản cho {email} và dữ liệu email đã lưu trong bộ nhớ cache sẽ bị xóa khỏi vWorkspace, nhưng không bị xóa khỏi nhà cung cấp dịch vụ email của bạn.",
-    "Remove {email}" : "Xóa {email}",
     "Show all subscribed mailboxes" : "Hiển thị tất cả các hộp thư đã đăng ký",
     "Show all mailboxes" : "Hiển thị tất cả các hộp thư",
     "Collapse mailboxes" : "Thu gọn hộp thư",
+    "_{total} message_::_{total} messages_" : ["{total} tin nhắn"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} thư chưa đọc trong tổng số {total} thư"],
+    "The mailbox and all messages in it will be deleted." : "Hộp thư và tất cả thư trong đó sẽ bị xóa.",
+    "Delete mailbox" : "Xóa hộp thư",
+    "Delete mailbox {name}" : "Xóa hộp thư {name}",
+    "An error occurred, unable to rename the mailbox." : "Đã xảy ra lỗi, không thể đổi tên hộp thư.",
     "Mark all as read" : "Đánh dấu tất cả như đã ",
     "Mark all messages of this mailbox as read" : "Đánh dấu tất cả các thư của hộp thư này là đã đọc",
     "Add submailbox" : "Thêm hộp thư con",
@@ -182,31 +194,24 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Xóa dữ liệu được lưu trong bộ nhớ cache cục bộ, trong trường hợp có sự cố với đồng bộ hóa.",
     "Subscribed" : "Đã đăng ký",
     "Sync in background" : "Đồng bộ trong nền",
-    "Delete mailbox" : "Xóa hộp thư",
-    "The mailbox and all messages in it will be deleted." : "Hộp thư và tất cả thư trong đó sẽ bị xóa.",
-    "Delete mailbox {name}" : "Xóa hộp thư {name}",
-    "An error occurred, unable to rename the mailbox." : "Đã xảy ra lỗi, không thể đổi tên hộp thư.",
-    "_{total} message_::_{total} messages_" : ["{total} tin nhắn"],
     "New message" : "Tin nhắn mới",
-    "Error sending your message" : "Lỗi khi gửi tin nhắn",
-    "Retry" : "Thử lại",
-    "Uploading attachments …" : "Đang tải lên các tệp đính kèm …",
-    "Sending …" : "Đang gửi …",
     "Reply" : "Trả lời",
     "No sent mailbox configured. Please pick one in the account settings." : "Không có hộp thư đã gửi nào được định cấu hình. Vui lòng chọn một trong cài đặt tài khoản.",
+    "Error sending your message" : "Lỗi khi gửi tin nhắn",
+    "Retry" : "Thử lại",
     "Contacts with this address" : "Liên hệ với địa chỉ này",
     "Add to Contact" : "Thêm liên hệ",
     "New Contact" : "ĐỊa chỉ liên hệ mới",
     "Copy to clipboard" : "Sao chép vào clipboard",
     "Contact name …" : "Tên người liên hệ …",
     "Add" : "Thêm",
+    "Clear" : "Xóa",
     "Close" : "Đóng",
     "Body" : "Thân",
     "Date" : "Date",
     "Tags" : "Nhãn",
     "Select tags" : "Chọn một thẻ",
     "Last 7 days" : "7 ngày trước",
-    "Clear" : "Xóa",
     "Sieve Port" : "Cổng Sieve",
     "Custom" : "Tùy chỉnh",
     "Sieve User" : "Người dùng Sieve",
@@ -215,26 +220,26 @@ OC.L10N.register(
     "Save sieve script" : "Lưu sieve script",
     "Signature …" : "Chữ ký …",
     "Save signature" : "Lưu chữ ký",
-    "Add tag" : "Thêm nhãn",
     "Tag already exists" : "Thẻ đã tồn tại",
-    "Not found" : "Không tìm thấy",
+    "Add tag" : "Thêm nhãn",
     "Could not load your message thread" : "Không thể tải chuỗi tin nhắn của bạn",
+    "Not found" : "Không tìm thấy",
     "Reply to sender only" : "Chỉ trả lời người gửi",
     "Mark as unread" : "Đánh dấu là chưa đọc",
     "Mark as read" : "Đánh dấu đã đọc",
     "Message source" : "Nguồn tin nhắn",
-    "No senders are trusted at the moment." : "Không có người gửi nào được tin cậy vào lúc này.",
     "Could not remove trusted sender {sender}" : "Không thể xóa người gửi đáng tin cậy {sender}",
-    "(organizer)" : "(organizer)",
+    "No senders are trusted at the moment." : "Không có người gửi nào được tin cậy vào lúc này.",
     "Untitled event" : "Sự kiện không tiêu đề",
+    "(organizer)" : "(organizer)",
     "Import into {calendar}" : "Nhập vào {calendar}",
     "Event imported into {calendar}" : "Sự kiện được nhập vào {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Chuyến bay {flightNr} từ {depAirport} đến {arrAirport}",
     "Airplane" : "Máy bay",
     "Reservation {id}" : "Dự phòng {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Chuyến bay {flightNr} từ {depAirport} đến {arrAirport}",
-    "Train" : "Tàu hỏa",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} từ {depStation} đến {arrStation}",
     "Train from {depStation} to {arrStation}" : "Đi tàu từ {depStation} đến {arrStation}",
+    "Train" : "Tàu hỏa",
     "Delete filter" : "Xóa bộ lọc ",
     "Actions" : "Hành động",
     "Mail app" : "Ứng dụng thư",
@@ -257,10 +262,6 @@ OC.L10N.register(
     "Submit" : "Gửi đi",
     "Account connected" : "Tài khoản đã được kết nối",
     "Connect your mail account" : "Kết nối tài khoản thư của bạn",
-    "Next week – {timeLocale}" : "Tuần sau - {timeLocale}",
-    "This weekend – {timeLocale}" : "Cuối tuần này - {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Ngày mai - {timeLocale}",
-    "Later today – {timeLocale}" : "Sau này - {timeLocale}",
     "All" : "Tất cả",
     "Drafts" : "Bản nháp",
     "Favorites" : "Ưa thích",
@@ -286,8 +287,7 @@ OC.L10N.register(
     "Redirect" : "Chuyển hướng",
     "The link leads to %s" : "Liên kết dẫn đến %s",
     "Continue to %s" : "Tiếp tục %s",
-    "Sieve filter rules" : "Quy tắc lọc Sieve",
-    "Sieve filter server" : "Máy chủ lọc Sieve",
-    "Unselect" : "Bỏ chọn"
+    "Uploading attachments …" : "Đang tải lên các tệp đính kèm …",
+    "Sending …" : "Đang gửi …"
 },
 "nplurals=1; plural=0;");
